% Monte-Carlo for thickness

rng(12345);

mat_name = 1;
baseline_temp = 70;
MC_number = 100;


MC_thick=zeros(MC_number,1);
nom_t0=0.33;

mat_name = 2;
baseline_temp = 70;
nom_t0 = 2* 0.165;
Nsamples = 1000;
Nlayers = 80;
my_std = 0.03;
delta_ramp = 1000;
delta_dwell = 10000;
S0 = -0.7;

MC_thick=zeros(Nsamples,1);


% Generate random properties for viscosity
mu=[0; 0.11];
corr_a_b = 0.97;
sig_a = 0.0537;
%sig_b = 0.473; % corresponds to 50% CoV when transformed to lognormal
sig_b = 0.2;
sig = [sig_a^2 corr_a_b*sig_a*sig_b; corr_a_b*sig_a*sig_b sig_b^2];
z = mvnrnd(mu,sig,Nsamples*Nlayers);


kk_distr=normrnd(0,0.0167,[1,Nsamples*Nlayers]);
t_distr = normrnd(0, 0.022, [1,Nsamples*Nlayers]);
    baseline_temp = 70;

tic
parfor mc=1:Nsamples
    my_temp = baseline_temp*(1 + normrnd(0, 0.1));
    my_struct = interpolate_properties(mat_name, my_temp);
    total = 0;
    
    delta_dwell = 1000 * (1+normrnd(0,0.1));
    S0 = -0.7 * (1 + normrnd(0,0.1));
    for i=1:Nlayers
        loc_str=my_struct;

        loc_str.a_sq = my_struct.a_sq*(1 + z((mc-1)*Nlayers + i,1));
        loc_str.a_bl=loc_str.a_sq;
        loc_str.b_sq=my_struct.b_sq * (exp(z((mc-1)*Nlayers + i,2)));
        loc_str.kk=my_struct.kk*(1 + kk_distr((mc-1)*Nlayers + i));
        
        loc_str.a_sq=my_struct.a_sq * (1+z((mc-1)*Nlayers + i,1));
        loc_str.a_bl=my_struct.a_bl* (1 + z((mc-1)*Nlayers + i,1));
        loc_str.b_bl=my_struct.b_bl*(1 + z((mc-1)*Nlayers + i,2));
        loc_str.b_sq=my_struct.b_sq;
        loc_str.kk = my_struct.kk * (1 + kk_distr((mc-1)*Nlayers + i));
        loc_str.w_h=my_struct.w_h;

        temp = compaction_1D_model_v10(2*nom_t0*(1+t_distr((mc-1)*Nlayers + i)),100, 100, loc_str, S0, delta_dwell);
        
        total = total + nom_t0 * (1 + t_distr((mc-1)*Nlayers + i)) * exp(temp);
    end
    MC_thick(mc)=total;
end
toc
