% Script to play with ODE solutions
% The script copy-pasted from Jonathan's script
%
% This version does not use any global variables. Everything is passed
% through arguments
%
% UNIFORM RAMPING UP TO 7 bar @ 90C
%
function my_output = compaction_1D_model_v10(thickness,my_length,my_width, my_struct, S0,delta_dwell)
    
    if (nargin < 4)
        % From Jonathan
        nur_a_Squeeze=-0.8378;
        nur_a_Bleed=-0.8378;
        nur_b_Squeeze=exp(-12.96);
        nur_b_Bleed=exp(-29.69);
        Newva=0.7953;
        Radius=3.5e-3;
        
        my_struct.a_sq = nur_a_Squeeze;
        my_struct.a_bl = nur_a_Bleed;
        my_struct.b_sq = nur_b_Squeeze;
        my_struct.b_bl = nur_b_Bleed;
        my_struct.kk = Newva;
    end

    kk= my_struct.kk;
  
    Radius=3.5e-3;
    
    h0=thickness;
    w0= my_width; l0 = my_length; 
    if ( w0/h0 > my_struct.w_h)
        w0=h0*my_struct.w_h;
    end

    d=sqrt(pi)*Radius;
    Af=0.5*(pi*(Radius)^2)/(kk^2);
    A0=pi*(Radius)^2; % Initial fibrevolume fraction=0.5
    alpha_cr = (1/(1+0.82))*atan(((2*Radius)^2)/(4*Af)); %x=0.82 
    alpha_cr_0 = asin((A0/Af)*sin(alpha_cr));
    tan_gamma_cr = (((4*A0)/((2*Radius)^2))-sin(2*alpha_cr_0))/(1-cos(2*alpha_cr_0));
    glock = -log(sqrt((2/3)*(h0/w0)*tan_gamma_cr + 1));  % Strain at edge locking
    elock = log((2/sqrt(pi))*(kk^2));  % Strain at bulk locking

    e_cr=glock;
    e_f=(4.0/3.0)*e_cr;
    
    % eps - true strain, eps_I - true strain rate, sig - nominal stress
    % solution of boundary value problem
    NumP = 1; TT = zeros(1000,1,'double'); 
    eps = zeros(1500,1,'double'); eps_I = zeros(1500,1,'double');  sig = zeros(1500,1,'double'); 
    width = zeros(1500,1,'double'); thick = zeros(1500,1,'double'); force = zeros(1500,1,'double');
    
    delta_ramp=1000*(1+normrnd(0,0.1)); 
    
    for iRamp=1:1
        step_stress= S0 / delta_ramp;
        sgm_t = linspace(TT(NumP,1),TT(NumP,1)+delta_ramp,20); % Time steps
        sgm=sgm_t*step_stress;
        
        CRL = @(t,y) ESuperposedEqNew4(t,y,sgm_t,sgm, w0, h0,l0, e_cr, e_f, my_struct);
        epsi = eps(NumP,1);
        options=odeset('Stats','on', 'RelTol', 1e-4, 'AbsTol', 1e-8);
        [t,yR] = ode15s(CRL,[TT(NumP,1) TT(NumP,1)+delta_ramp], epsi, options);
        for iT=1:size(t)
            iI = NumP+iT-1;
            eps(iI,1) = yR(iT,1);% epsi = eps(iI,1);
            eps_I(iI,1) = CRL(t(iT,1),eps(iI,1));
        end
        
        TT(NumP:NumP + numel(t)-1,1) = t(:); NumP =NumP + numel(t)-1;
        sgm_t = linspace(TT(NumP,1),TT(NumP,1)+delta_dwell,100);
        sgm = sgm_t*0 + S0;
        CRL = @(t,y) ESuperposedEqNew4(t,y,sgm_t,sgm,w0,h0,l0,e_cr,e_f,my_struct); 
        epsi = eps(NumP,1);
        [t,yR] = ode15s(CRL,[TT(NumP,1) TT(NumP,1)+delta_dwell], epsi, options);
        
        for iT=1:size(t)
            iI = NumP+iT-1;
            eps(iI,1) = yR(iT,1);% epsi = eps(iI,1);
            eps_I(iI,1) = CRL(t(iT,1),eps(iI,1));
        end
        TT(NumP:NumP + numel(t)-1,1) = t(:); NumP =NumP + numel(t)-1;
    end
    my_output=eps(iI);
